==> texinfo-6.8.90.tar.xz: texinfo-6.8.90/tp/t/results/misc_commands/also_not_line.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text %result_indices_sort_strings);

use utf8;

$result_trees{'also_not_line'} = {
  'contents' => [
    {
      'contents' => [
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'page '
            }
          ],
          'parent' => {},
          'type' => 'paragraph'
        },
        {
          'args' => [
            {
              'parent' => {},
              'text' => ' 
',
              'type' => 'misc_arg'
            }
          ],
          'cmdname' => 'page',
          'parent' => {}
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'noindent '
            },
            {
              'cmdname' => 'noindent',
              'parent' => {},
              'source_info' => {
                'file_name' => '',
                'line_nr' => 4,
                'macro' => ''
              }
            },
            {
              'parent' => {},
              'text' => ' ',
              'type' => 'ignorable_spaces_after_command'
            },
            {
              'parent' => {},
              'text' => 'refill '
            },
            {
              'cmdname' => 'refill',
              'parent' => {}
            },
            {
              'parent' => {},
              'text' => ' something
'
            }
          ],
          'parent' => {},
          'type' => 'paragraph'
        },
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'cmdname' => 'noindent',
          'parent' => {},
          'source_info' => {
            'file_name' => '',
            'line_nr' => 6,
            'macro' => ''
          }
        },
        {
          'parent' => {},
          'text' => '     ',
          'type' => 'ignorable_spaces_after_command'
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'noindent at beginning of line
'
            },
            {
              'cmdname' => 'noindent',
              'parent' => {},
              'source_info' => {
                'file_name' => '',
                'line_nr' => 7,
                'macro' => ''
              }
            },
            {
              'parent' => {},
              'text' => '  
',
              'type' => 'ignorable_spaces_after_command'
            },
            {
              'parent' => {},
              'text' => 'noindent on the preceding line
'
            },
            {
              'parent' => {},
              'text' => '  '
            },
            {
              'cmdname' => 'noindent',
              'parent' => {},
              'source_info' => {
                'file_name' => '',
                'line_nr' => 9,
                'macro' => ''
              }
            },
            {
              'parent' => {},
              'text' => '    ',
              'type' => 'ignorable_spaces_after_command'
            },
            {
              'parent' => {},
              'text' => 'noindent after space at beginning of line
'
            }
          ],
          'extra' => {
            'noindent' => 1
          },
          'parent' => {},
          'type' => 'paragraph'
        },
        {
          'args' => [
            {
              'parent' => {},
              'text' => '         page at beginning of line
',
              'type' => 'misc_arg'
            }
          ],
          'cmdname' => 'page',
          'parent' => {}
        },
        {
          'args' => [
            {
              'parent' => {},
              'text' => '
',
              'type' => 'misc_arg'
            }
          ],
          'cmdname' => 'page',
          'parent' => {}
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'After page on its own line.
'
            }
          ],
          'parent' => {},
          'type' => 'paragraph'
        },
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'page '
            }
          ],
          'parent' => {},
          'type' => 'paragraph'
        },
        {
          'args' => [
            {
              'parent' => {},
              'text' => '   
',
              'type' => 'misc_arg'
            }
          ],
          'cmdname' => 'page',
          'parent' => {}
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'noindent '
            },
            {
              'cmdname' => 'noindent',
              'parent' => {},
              'source_info' => {
                'file_name' => '',
                'line_nr' => 15,
                'macro' => ''
              }
            },
            {
              'parent' => {},
              'text' => '    ',
              'type' => 'ignorable_spaces_after_command'
            },
            {
              'parent' => {},
              'text' => 'refill '
            },
            {
              'cmdname' => 'refill',
              'parent' => {}
            },
            {
              'parent' => {},
              'text' => ' 
'
            },
            {
              'parent' => {},
              'text' => 'novalidate '
            },
            {
              'args' => [
                {
                  'parent' => {},
                  'text' => ' something
',
                  'type' => 'misc_arg'
                }
              ],
              'cmdname' => 'novalidate',
              'parent' => {},
              'source_info' => {
                'file_name' => '',
                'line_nr' => 16,
                'macro' => ''
              }
            }
          ],
          'parent' => {},
          'type' => 'paragraph'
        },
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'args' => [
            {
              'contents' => [
                {
                  'parent' => {},
                  'text' => 'special'
                }
              ],
              'extra' => {
                'spaces_after_argument' => '
'
              },
              'parent' => {},
              'type' => 'line_arg'
            }
          ],
          'cmdname' => 'subheading',
          'extra' => {
            'spaces_before_argument' => ' '
          },
          'parent' => {},
          'source_info' => {
            'file_name' => '',
            'line_nr' => 18,
            'macro' => ''
          }
        },
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'Only valid between iftex:
'
            },
            {
              'parent' => {},
              'text' => 'vskip '
            },
            {
              'args' => [
                {
                  'parent' => {},
                  'text' => ' 
',
                  'type' => 'misc_arg'
                }
              ],
              'cmdname' => 'vskip',
              'extra' => {
                'misc_args' => [
                  ' 
'
                ]
              },
              'parent' => {}
            }
          ],
          'parent' => {},
          'type' => 'paragraph'
        },
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'exdent '
            }
          ],
          'parent' => {},
          'type' => 'paragraph'
        },
        {
          'args' => [
            {
              'contents' => [
                {
                  'parent' => {},
                  'text' => 'line after exdent'
                }
              ],
              'extra' => {
                'spaces_after_argument' => '
'
              },
              'parent' => {},
              'type' => 'line_arg'
            }
          ],
          'cmdname' => 'exdent',
          'extra' => {
            'spaces_before_argument' => ' '
          },
          'parent' => {},
          'source_info' => {
            'file_name' => '',
            'line_nr' => 23,
            'macro' => ''
          }
        }
      ],
      'parent' => {},
      'type' => 'before_node_section'
    }
  ],
  'type' => 'document_root'
};
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[2]{'contents'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[2];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[3]{'args'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[3];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[4]{'contents'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[4];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[4]{'contents'}[1]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[4];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[4]{'contents'}[2]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[4];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[4]{'contents'}[3]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[4];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[4]{'contents'}[4]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[4];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[4]{'contents'}[5]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[4];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[4]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[5]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[6]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[7]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[8]{'contents'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[8];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[8]{'contents'}[1]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[8];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[8]{'contents'}[2]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[8];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[8]{'contents'}[3]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[8];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[8]{'contents'}[4]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[8];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[8]{'contents'}[5]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[8];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[8]{'contents'}[6]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[8];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[8]{'contents'}[7]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[8];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[8]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[9]{'args'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[9];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[9]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[10]{'args'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[10];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[10]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[11]{'contents'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[11];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[11]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[12]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[13]{'contents'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[13];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[13]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[14]{'args'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[14];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[14]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[15]{'contents'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[15];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[15]{'contents'}[1]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[15];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[15]{'contents'}[2]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[15];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[15]{'contents'}[3]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[15];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[15]{'contents'}[4]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[15];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[15]{'contents'}[5]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[15];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[15]{'contents'}[6]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[15];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[15]{'contents'}[7]{'args'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[15]{'contents'}[7];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[15]{'contents'}[7]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[15];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[15]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[16]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[17]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[17]{'args'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[17]{'args'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[17];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[17]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[18]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[19]{'contents'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[19];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[19]{'contents'}[1]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[19];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[19]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[19]{'contents'}[2];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[19]{'contents'}[2]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[19];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[19]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[20]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[21]{'contents'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[21];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[21]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[22]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[22]{'args'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[22]{'args'}[0]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0]{'contents'}[22];
$result_trees{'also_not_line'}{'contents'}[0]{'contents'}[22]{'parent'} = $result_trees{'also_not_line'}{'contents'}[0];
$result_trees{'also_not_line'}{'contents'}[0]{'parent'} = $result_trees{'also_not_line'};

$result_texis{'also_not_line'} = '

page @page 
noindent @noindent refill @refill something

@noindent     noindent at beginning of line
@noindent  
noindent on the preceding line
  @noindent    noindent after space at beginning of line
@page         page at beginning of line
@page
After page on its own line.

page @page   
noindent @noindent    refill @refill 
novalidate @novalidate something

@subheading special

Only valid between iftex:
vskip @vskip 

exdent @exdent line after exdent
';


$result_texts{'also_not_line'} = '

page 
noindent refill  something

noindent at beginning of line
noindent on the preceding line
  noindent after space at beginning of line


After page on its own line.

page 
noindent refill  
novalidate 
special
-------

Only valid between iftex:
vskip 
exdent line after exdent
';

$result_errors{'also_not_line'} = [
  {
    'error_line' => 'warning: @page should only appear at the beginning of a line
',
    'file_name' => '',
    'line_nr' => 3,
    'macro' => '',
    'text' => '@page should only appear at the beginning of a line',
    'type' => 'warning'
  },
  {
    'error_line' => 'warning: @refill is obsolete
',
    'file_name' => '',
    'line_nr' => 4,
    'macro' => '',
    'text' => '@refill is obsolete',
    'type' => 'warning'
  },
  {
    'error_line' => 'warning: @page should only appear at the beginning of a line
',
    'file_name' => '',
    'line_nr' => 14,
    'macro' => '',
    'text' => '@page should only appear at the beginning of a line',
    'type' => 'warning'
  },
  {
    'error_line' => 'warning: @refill is obsolete
',
    'file_name' => '',
    'line_nr' => 15,
    'macro' => '',
    'text' => '@refill is obsolete',
    'type' => 'warning'
  },
  {
    'error_line' => 'warning: @novalidate should only appear at the beginning of a line
',
    'file_name' => '',
    'line_nr' => 16,
    'macro' => '',
    'text' => '@novalidate should only appear at the beginning of a line',
    'type' => 'warning'
  },
  {
    'error_line' => 'warning: @exdent should only appear at the beginning of a line
',
    'file_name' => '',
    'line_nr' => 23,
    'macro' => '',
    'text' => '@exdent should only appear at the beginning of a line',
    'type' => 'warning'
  }
];


$result_floats{'also_not_line'} = {};


1;

==> texinfo_7.0.3.orig.tar.xz: texinfo-7.0.3/tp/t/results/misc_commands/also_not_line.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text %result_indices_sort_strings);

use utf8;

$result_trees{'also_not_line'} = {
  'contents' => [
    {
      'contents' => [
        {
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'text' => 'page '
            }
          ],
          'type' => 'paragraph'
        },
        {
          'args' => [
            {
              'text' => ' 
',
              'type' => 'misc_arg'
            }
          ],
          'cmdname' => 'page'
        },
        {
          'contents' => [
            {
              'text' => 'noindent '
            },
            {
              'cmdname' => 'noindent',
              'source_info' => {
                'file_name' => '',
                'line_nr' => 4,
                'macro' => ''
              }
            },
            {
              'text' => ' ',
              'type' => 'ignorable_spaces_after_command'
            },
            {
              'text' => 'refill '
            },
            {
              'cmdname' => 'refill'
            },
            {
              'text' => ' something
'
            }
          ],
          'type' => 'paragraph'
        },
        {
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'cmdname' => 'noindent',
          'source_info' => {
            'file_name' => '',
            'line_nr' => 6,
            'macro' => ''
          }
        },
        {
          'text' => '     ',
          'type' => 'ignorable_spaces_after_command'
        },
        {
          'contents' => [
            {
              'text' => 'noindent at beginning of line
'
            },
            {
              'cmdname' => 'noindent',
              'source_info' => {
                'file_name' => '',
                'line_nr' => 7,
                'macro' => ''
              }
            },
            {
              'text' => '  
',
              'type' => 'ignorable_spaces_after_command'
            },
            {
              'text' => 'noindent on the preceding line
'
            },
            {
              'text' => '  '
            },
            {
              'cmdname' => 'noindent',
              'source_info' => {
                'file_name' => '',
                'line_nr' => 9,
                'macro' => ''
              }
            },
            {
              'text' => '    ',
              'type' => 'ignorable_spaces_after_command'
            },
            {
              'text' => 'noindent after space at beginning of line
'
            }
          ],
          'extra' => {
            'noindent' => 1
          },
          'type' => 'paragraph'
        },
        {
          'args' => [
            {
              'text' => '         page at beginning of line
',
              'type' => 'misc_arg'
            }
          ],
          'cmdname' => 'page'
        },
        {
          'args' => [
            {
              'text' => '
',
              'type' => 'misc_arg'
            }
          ],
          'cmdname' => 'page'
        },
        {
          'contents' => [
            {
              'text' => 'After page on its own line.
'
            }
          ],
          'type' => 'paragraph'
        },
        {
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'text' => 'page '
            }
          ],
          'type' => 'paragraph'
        },
        {
          'args' => [
            {
              'text' => '   
',
              'type' => 'misc_arg'
            }
          ],
          'cmdname' => 'page'
        },
        {
          'contents' => [
            {
              'text' => 'noindent '
            },
            {
              'cmdname' => 'noindent',
              'source_info' => {
                'file_name' => '',
                'line_nr' => 15,
                'macro' => ''
              }
            },
            {
              'text' => '    ',
              'type' => 'ignorable_spaces_after_command'
            },
            {
              'text' => 'refill '
            },
            {
              'cmdname' => 'refill'
            },
            {
              'text' => ' 
'
            },
            {
              'text' => 'novalidate '
            },
            {
              'args' => [
                {
                  'text' => ' something
',
                  'type' => 'misc_arg'
                }
              ],
              'cmdname' => 'novalidate',
              'source_info' => {
                'file_name' => '',
                'line_nr' => 16,
                'macro' => ''
              }
            }
          ],
          'type' => 'paragraph'
        },
        {
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'args' => [
            {
              'contents' => [
                {
                  'text' => 'special'
                }
              ],
              'extra' => {
                'spaces_after_argument' => '
'
              },
              'type' => 'line_arg'
            }
          ],
          'cmdname' => 'subheading',
          'extra' => {
            'spaces_before_argument' => ' '
          },
          'source_info' => {
            'file_name' => '',
            'line_nr' => 18,
            'macro' => ''
          }
        },
        {
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'text' => 'Only valid between iftex:
'
            },
            {
              'text' => 'vskip '
            },
            {
              'args' => [
                {
                  'text' => ' 
',
                  'type' => 'misc_arg'
                }
              ],
              'cmdname' => 'vskip',
              'extra' => {
                'misc_args' => [
                  ' 
'
                ]
              }
            }
          ],
          'type' => 'paragraph'
        },
        {
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'text' => 'exdent '
            }
          ],
          'type' => 'paragraph'
        },
        {
          'args' => [
            {
              'contents' => [
                {
                  'text' => 'line after exdent'
                }
              ],
              'extra' => {
                'spaces_after_argument' => '
'
              },
              'type' => 'line_arg'
            }
          ],
          'cmdname' => 'exdent',
          'extra' => {
            'spaces_before_argument' => ' '
          },
          'source_info' => {
            'file_name' => '',
            'line_nr' => 23,
            'macro' => ''
          }
        }
      ],
      'type' => 'before_node_section'
    }
  ],
  'type' => 'document_root'
};

$result_texis{'also_not_line'} = '

page @page 
noindent @noindent refill @refill something

@noindent     noindent at beginning of line
@noindent  
noindent on the preceding line
  @noindent    noindent after space at beginning of line
@page         page at beginning of line
@page
After page on its own line.

page @page   
noindent @noindent    refill @refill 
novalidate @novalidate something

@subheading special

Only valid between iftex:
vskip @vskip 

exdent @exdent line after exdent
';


$result_texts{'also_not_line'} = '

page 
noindent refill  something

noindent at beginning of line
noindent on the preceding line
  noindent after space at beginning of line


After page on its own line.

page 
noindent refill  
novalidate 
special
-------

Only valid between iftex:
vskip 
exdent line after exdent
';

$result_errors{'also_not_line'} = [
  {
    'error_line' => 'warning: @page should only appear at the beginning of a line
',
    'file_name' => '',
    'line_nr' => 3,
    'macro' => '',
    'text' => '@page should only appear at the beginning of a line',
    'type' => 'warning'
  },
  {
    'error_line' => 'warning: @refill is obsolete
',
    'file_name' => '',
    'line_nr' => 4,
    'macro' => '',
    'text' => '@refill is obsolete',
    'type' => 'warning'
  },
  {
    'error_line' => 'warning: @page should only appear at the beginning of a line
',
    'file_name' => '',
    'line_nr' => 14,
    'macro' => '',
    'text' => '@page should only appear at the beginning of a line',
    'type' => 'warning'
  },
  {
    'error_line' => 'warning: @refill is obsolete
',
    'file_name' => '',
    'line_nr' => 15,
    'macro' => '',
    'text' => '@refill is obsolete',
    'type' => 'warning'
  },
  {
    'error_line' => 'warning: @novalidate should only appear at the beginning of a line
',
    'file_name' => '',
    'line_nr' => 16,
    'macro' => '',
    'text' => '@novalidate should only appear at the beginning of a line',
    'type' => 'warning'
  },
  {
    'error_line' => 'warning: @exdent should only appear at the beginning of a line
',
    'file_name' => '',
    'line_nr' => 23,
    'macro' => '',
    'text' => '@exdent should only appear at the beginning of a line',
    'type' => 'warning'
  }
];


$result_floats{'also_not_line'} = {};


1;
